@@ -1,20 +1,18 @@
 /*
  * Copyright 2015-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * This program is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 3 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "musicalbum.h"
@@ -282,6 +280,7 @@ private Q_SLOTS:
         QSignalSpy endRemoveRowsSpy(&albumsModel, &AllAlbumsModel::rowsRemoved);
         QSignalSpy dataChangedSpy(&albumsModel, &AllAlbumsModel::dataChanged);
 
+        QCOMPARE(albumsModel.rowCount(), 0);
         QCOMPARE(beginInsertRowsSpy.count(), 0);
         QCOMPARE(endInsertRowsSpy.count(), 0);
         QCOMPARE(beginRemoveRowsSpy.count(), 0);
@@ -290,15 +289,16 @@ private Q_SLOTS:
 
         musicDb.insertTracksList(mNewTracks, mNewCovers, QStringLiteral("autoTest"));
 
-        while(beginInsertRowsSpy.count() < 4) {
+        while(beginInsertRowsSpy.count() < 5) {
             QCOMPARE(beginInsertRowsSpy.wait(500), true);
         }
-        while(endInsertRowsSpy.count() < 4) {
+        while(endInsertRowsSpy.count() < 5) {
             QCOMPARE(endInsertRowsSpy.wait(500), true);
         }
 
-        QCOMPARE(beginInsertRowsSpy.count(), 4);
-        QCOMPARE(endInsertRowsSpy.count(), 4);
+        QCOMPARE(albumsModel.rowCount(), 5);
+        QCOMPARE(beginInsertRowsSpy.count(), 5);
+        QCOMPARE(endInsertRowsSpy.count(), 5);
         QCOMPARE(beginRemoveRowsSpy.count(), 0);
         QCOMPARE(endRemoveRowsSpy.count(), 0);
         QCOMPARE(dataChangedSpy.count(), 0);
@@ -322,6 +322,7 @@ private Q_SLOTS:
             QCOMPARE(endRemoveRowsSpy.wait(500), true);
         }
 
+        QCOMPARE(albumsModel.rowCount(), 4);
         QCOMPARE(beginInsertRowsSpy.count(), 5);
         QCOMPARE(endInsertRowsSpy.count(), 5);
         QCOMPARE(beginRemoveRowsSpy.count(), 1);
