@@ -1,20 +1,18 @@
 /*
  * Copyright 2015-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * This program is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 3 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "file/localfilelisting.h"
@@ -294,9 +292,9 @@ private Q_SLOTS:
         }
         QCOMPARE(errorWatchingFilesSpy.count(), 0);
 
-        auto firstNewTracksSignal = tracksListSpy.at(0);
+        const auto &firstNewTracksSignal = tracksListSpy.at(0);
         auto firstNewTracks = firstNewTracksSignal.at(0).value<QList<MusicAudioTrack>>();
-        auto secondNewTracksSignal = tracksListSpy.at(1);
+        const auto &secondNewTracksSignal = tracksListSpy.at(1);
         auto secondNewTracks = secondNewTracksSignal.at(0).value<QList<MusicAudioTrack>>();
         auto newCovers = secondNewTracksSignal.at(1).value<QHash<QString, QUrl>>();
 
