@@ -1,20 +1,18 @@
 /*
  * Copyright 2016-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * This program is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 3 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef DATABASEINTERFACE_H
@@ -59,20 +57,22 @@ public:
         Id,
     };
 
+    Q_ENUM(AlbumData)
+
     enum PropertyType {
         DatabaseId,
         DisplayRole,
         SecondaryRole,
     };
 
-    Q_ENUMS(PropertyType)
+    Q_ENUM(PropertyType)
 
     enum AlbumDiscsCount {
         SingleDiscAlbum,
         MultipleDiscsAlbum,
     };
 
-    Q_ENUMS(AlbumDiscsCounts)
+    Q_ENUM(AlbumDiscsCount)
 
     explicit DatabaseInterface(QObject *parent = nullptr);
 
@@ -164,6 +164,10 @@ private:
         ModifiedTrackFileInsert,
     };
 
+    void initChangesTrackers();
+
+    void recordModifiedTrack(qulonglong trackId);
+
     bool startTransaction() const;
 
     bool finishTransaction() const;
@@ -205,13 +209,11 @@ private:
 
     qulonglong insertAlbum(const QString &title, const QString &albumArtist, const QString &trackArtist,
                            const QString &trackPath, const QUrl &albumArtURI, int tracksCount,
-                           AlbumDiscsCount isSingleDiscAlbum, QList<qulonglong> &newAlbumIds,
-                           QList<qulonglong> &newArtistsIds);
+                           AlbumDiscsCount isSingleDiscAlbum);
 
-    bool updateAlbumFromId(qulonglong albumId, const QUrl &albumArtUri, const MusicAudioTrack &currentTrack,
-                           QList<qulonglong> &newArtistsIds);
+    bool updateAlbumFromId(qulonglong albumId, const QUrl &albumArtUri, const MusicAudioTrack &currentTrack);
 
-    qulonglong insertArtist(const QString &name, QList<qulonglong> &newArtistsIds);
+    qulonglong insertArtist(const QString &name);
 
     qulonglong internalArtistIdFromName(const QString &name);
 
@@ -221,8 +223,7 @@ private:
 
     void removeTrackInDatabase(qulonglong trackId);
 
-    void updateTrackInDatabase(const MusicAudioTrack &oneTrack, qulonglong albumId,
-                               QList<qulonglong> &newArtistsIds);
+    void updateTrackInDatabase(const MusicAudioTrack &oneTrack, qulonglong albumId);
 
     void removeAlbumInDatabase(qulonglong albumId);
 
@@ -239,16 +240,15 @@ private:
     int computeTrackPriority(qulonglong trackId, const QUrl &fileName);
 
     qulonglong internalInsertTrack(const MusicAudioTrack &oneModifiedTrack, const QHash<QString, QUrl> &covers,
-                                   qulonglong originTrackId, QSet<qulonglong> &modifiedAlbumIds, TrackFileInsertType insertType,
-                                   QList<qulonglong> &newAlbumIds, QList<qulonglong> &newArtistsIds, QSet<qulonglong> &modifiedTrackIds);
+                                   qulonglong originTrackId, TrackFileInsertType insertType);
 
     MusicAudioTrack buildTrackFromDatabaseRecord(const QSqlRecord &trackRecord) const;
 
-    void internalRemoveTracksList(const QList<QUrl> &removedTracks, QList<qulonglong> &newArtistsIds);
+    void internalRemoveTracksList(const QList<QUrl> &removedTracks);
 
-    void internalRemoveTracksList(const QHash<QUrl, QDateTime> &removedTracks, qulonglong sourceId, QList<qulonglong> &newArtistsIds);
+    void internalRemoveTracksList(const QHash<QUrl, QDateTime> &removedTracks, qulonglong sourceId);
 
-    void internalRemoveTracksWithoutMapping(QList<qulonglong> &newArtistsIds);
+    void internalRemoveTracksWithoutMapping();
 
     QUrl internalAlbumArtUriFromAlbumId(qulonglong albumId);
 
