@@ -1,20 +1,18 @@
 /*
  * Copyright 2016 Matthieu Gallien <matthieu_gallien@yahoo.fr>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * This program is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 3 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef MANAGEAUDIOPLAYER_H
@@ -86,7 +84,7 @@ class ELISALIB_EXPORT ManageAudioPlayer : public QObject
                WRITE setPlayerError
                NOTIFY playerErrorChanged)
 
-    Q_PROPERTY(int audioDuration
+    Q_PROPERTY(qint64 audioDuration
                READ audioDuration
                WRITE setAudioDuration
                NOTIFY audioDurationChanged)
@@ -96,12 +94,12 @@ class ELISALIB_EXPORT ManageAudioPlayer : public QObject
                WRITE setPlayerIsSeekable
                NOTIFY playerIsSeekableChanged)
 
-    Q_PROPERTY(int playerPosition
+    Q_PROPERTY(qint64 playerPosition
                READ playerPosition
                WRITE setPlayerPosition
                NOTIFY playerPositionChanged)
 
-    Q_PROPERTY(int playControlPosition
+    Q_PROPERTY(qint64 playControlPosition
                READ playControlPosition
                WRITE setPlayControlPosition
                NOTIFY playControlPositionChanged)
@@ -139,13 +137,13 @@ public:
 
     QMediaPlayer::Error playerError() const;
 
-    int audioDuration() const;
+    qint64 audioDuration() const;
 
     bool playerIsSeekable() const;
 
-    int playerPosition() const;
+    qint64 playerPosition() const;
 
-    int playControlPosition() const;
+    qint64 playControlPosition() const;
 
     QVariantMap persistentState() const;
 
@@ -193,7 +191,7 @@ Q_SIGNALS:
 
     void persistentStateChanged();
 
-    void seek(int position);
+    void seek(qint64 position);
 
     void titleRoleChanged();
 
@@ -229,11 +227,11 @@ public Q_SLOTS:
 
     void stop();
 
-    void setAudioDuration(int audioDuration);
+    void setAudioDuration(qint64 audioDuration);
 
     void setPlayerIsSeekable(bool playerIsSeekable);
 
-    void setPlayerPosition(int playerPosition);
+    void setPlayerPosition(qint64 playerPosition);
 
     void setPlayControlPosition(int playerPosition);
 
@@ -297,7 +295,7 @@ private:
 
     bool mPlayerIsSeekable = false;
 
-    int mPlayerPosition = 0;
+    qint64 mPlayerPosition = 0;
 
     QVariantMap mPersistentState;
 
