@@ -1,20 +1,18 @@
 /*
  * Copyright 2016 Matthieu Gallien <matthieu_gallien@yahoo.fr>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * This program is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 3 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "manageheaderbar.h"
@@ -88,7 +86,7 @@ int ManageHeaderBar::albumIdRole() const
 QVariant ManageHeaderBar::album() const
 {
     if (!mCurrentTrack.isValid()) {
-        return QStringLiteral("");
+        return QString();
     }
 
     return mCurrentTrack.data(mAlbumRole);
@@ -97,7 +95,7 @@ QVariant ManageHeaderBar::album() const
 QVariant ManageHeaderBar::title() const
 {
     if (!mCurrentTrack.isValid()) {
-        return QStringLiteral("");
+        return QString();
     }
 
     return mCurrentTrack.data(mTitleRole);
@@ -106,7 +104,7 @@ QVariant ManageHeaderBar::title() const
 QVariant ManageHeaderBar::artist() const
 {
     if (!mCurrentTrack.isValid()) {
-        return QStringLiteral("");
+        return QString();
     }
 
     return mCurrentTrack.data(mArtistRole);
