@@ -1,20 +1,18 @@
 /*
  * Copyright 2016-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * This program is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 3 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "musicalbum.h"
@@ -25,10 +23,11 @@
 #include <QString>
 #include <QUrl>
 #include <QMap>
+#include <QSharedData>
 
 #include <QDebug>
 
-class MusicAlbumPrivate
+class MusicAlbumPrivate : public QSharedData
 {
 public:
 
@@ -50,47 +49,27 @@ public:
 
     QList<MusicAudioTrack> mTracks;
 
+    QStringList mGenres;
+
     int mTracksCount = 0;
 
     bool mIsValid = false;
 
     bool mIsSingleDiscAlbum = true;
 
-    QStringList mGenres;
-
 };
 
-MusicAlbum::MusicAlbum() : d(std::make_unique<MusicAlbumPrivate>())
+MusicAlbum::MusicAlbum() : d(new MusicAlbumPrivate())
 {
 }
 
-MusicAlbum::MusicAlbum(MusicAlbum &&other)
-{
-    d.swap(other.d);
-}
+MusicAlbum::MusicAlbum(MusicAlbum &&other) noexcept = default;
 
-MusicAlbum::MusicAlbum(const MusicAlbum &other) : d(std::make_unique<MusicAlbumPrivate>(*other.d))
-{
-}
+MusicAlbum::MusicAlbum(const MusicAlbum &other) = default;
 
-MusicAlbum& MusicAlbum::operator=(MusicAlbum &&other)
-{
-    if (&other != this) {
-        d.reset();
-        d.swap(other.d);
-    }
+MusicAlbum& MusicAlbum::operator=(MusicAlbum &&other) noexcept = default;
 
-    return *this;
-}
-
-MusicAlbum& MusicAlbum::operator=(const MusicAlbum &other)
-{
-    if (&other != this) {
-        (*d) = (*other.d);
-    }
-
-    return *this;
-}
+MusicAlbum& MusicAlbum::operator=(const MusicAlbum &other) = default;
 
 MusicAlbum::~MusicAlbum()
 = default;
