@@ -1,20 +1,18 @@
 /*
  * Copyright 2016-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * This program is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 3 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef MUSICALBUM_H
@@ -29,6 +27,7 @@
 #include <QMap>
 #include <QStringList>
 #include <QMetaType>
+#include <QSharedDataPointer>
 
 #include <memory>
 
@@ -42,11 +41,11 @@ public:
 
     MusicAlbum();
 
-    MusicAlbum(MusicAlbum &&other);
+    MusicAlbum(MusicAlbum &&other) noexcept;
 
     MusicAlbum(const MusicAlbum &other);
 
-    MusicAlbum& operator=(MusicAlbum &&other);
+    MusicAlbum& operator=(MusicAlbum &&other) noexcept;
 
     MusicAlbum& operator=(const MusicAlbum &other);
 
@@ -128,7 +127,7 @@ public:
 
 private:
 
-    std::unique_ptr<MusicAlbumPrivate> d;
+    QSharedDataPointer<MusicAlbumPrivate> d;
 
 };
 
@@ -136,6 +135,8 @@ ELISALIB_EXPORT QDebug operator<<(QDebug stream, const MusicAlbum &data);
 
 ELISALIB_EXPORT bool operator==(const MusicAlbum &album1, const MusicAlbum &album2);
 
+Q_DECLARE_TYPEINFO(MusicAlbum, Q_MOVABLE_TYPE);
+
 Q_DECLARE_METATYPE(MusicAlbum)
 
 #endif // MUSICALBUM_H
