@@ -1,20 +1,18 @@
 /*
  * Copyright 2016-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * This program is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 3 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "musicartist.h"
@@ -22,9 +20,11 @@
 #include <QtGlobal>
 #include <QString>
 #include <QStringList>
+#include <QSharedData>
+
 #include <QDebug>
 
-class MusicArtistPrivate
+class MusicArtistPrivate : public QSharedData
 {
 public:
 
@@ -40,37 +40,17 @@ public:
 
 };
 
-MusicArtist::MusicArtist() : d(std::make_unique<MusicArtistPrivate>())
+MusicArtist::MusicArtist() : d(new MusicArtistPrivate())
 {
 }
 
-MusicArtist::MusicArtist(MusicArtist &&other)
-{
-    d.swap(other.d);
-}
+MusicArtist::MusicArtist(MusicArtist &&other) noexcept = default;
 
-MusicArtist::MusicArtist(const MusicArtist &other) : d(std::make_unique<MusicArtistPrivate>(*other.d))
-{
-}
+MusicArtist::MusicArtist(const MusicArtist &other) = default;
 
-MusicArtist& MusicArtist::operator=(MusicArtist &&other)
-{
-    if (&other != this) {
-        d.reset();
-        d.swap(other.d);
-    }
+MusicArtist& MusicArtist::operator=(MusicArtist &&other) noexcept = default;
 
-    return *this;
-}
-
-MusicArtist &MusicArtist::operator=(const MusicArtist &other)
-{
-    if (&other != this) {
-        (*d) = (*other.d);
-    }
-
-    return *this;
-}
+MusicArtist &MusicArtist::operator=(const MusicArtist &other) = default;
 
 MusicArtist::~MusicArtist()
 = default;
