@@ -1,20 +1,18 @@
 /*
  * Copyright 2016-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * This program is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 3 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef MUSICAUDIOTRACK_H
@@ -26,6 +24,7 @@
 #include <QTime>
 #include <QUrl>
 #include <QMetaType>
+#include <QSharedDataPointer>
 
 #include <memory>
 
@@ -72,49 +71,49 @@ public:
 
     qulonglong albumId() const;
 
-    void setId(const QString &value) const;
+    void setId(const QString &value);
 
     QString id() const;
 
-    void setParentId(const QString &value) const;
+    void setParentId(const QString &value);
 
     QString parentId() const;
 
-    void setTitle(const QString &value) const;
+    void setTitle(const QString &value);
 
     QString title() const;
 
-    void setArtist(const QString &value) const;
+    void setArtist(const QString &value);
 
     QString artist() const;
 
-    void setAlbumName(const QString &value) const;
+    void setAlbumName(const QString &value);
 
     QString albumName() const;
 
-    void setAlbumArtist(const QString &value) const;
+    void setAlbumArtist(const QString &value);
 
     QString albumArtist() const;
 
-    void setGenre(const QString &value) const;
+    void setGenre(const QString &value);
 
     QString genre() const;
 
-    void setComposer(const QString &value) const;
+    void setComposer(const QString &value);
 
     QString composer() const;
 
-    void setLyricist(const QString &value) const;
+    void setLyricist(const QString &value);
 
     QString lyricist() const;
 
-    void setComment(const QString &value) const;
+    void setComment(const QString &value);
 
     QString comment() const;
 
     bool isValidAlbumArtist() const;
 
-    void setAlbumCover(const QUrl &value) const;
+    void setAlbumCover(const QUrl &value);
 
     QUrl albumCover() const;
 
@@ -154,7 +153,7 @@ public:
 
     const QUrl& resourceURI() const;
 
-    void setRating(int value) const;
+    void setRating(int value);
 
     int rating() const;
 
@@ -164,12 +163,14 @@ public:
 
 private:
 
-    std::unique_ptr<MusicAudioTrackPrivate> d;
+    QSharedDataPointer<MusicAudioTrackPrivate> d;
 
 };
 
 ELISALIB_EXPORT QDebug operator<<(QDebug stream, const MusicAudioTrack &data);
 
+Q_DECLARE_TYPEINFO(MusicAudioTrack, Q_MOVABLE_TYPE);
+
 Q_DECLARE_METATYPE(MusicAudioTrack)
 
 #endif // MUSICAUDIOTRACK_H
